@@ -47,10 +47,14 @@ def fallback_cache(func: RT) -> RT:
     @functools.wraps(func)
     async def wrapped(*args, **kwargs):
         try:
-            cache.last_run_result = await func(*args, **kwargs)
+            last_run_result = await func(*args, **kwargs)
+            cache.last_run_result = last_run_result
         except Exception as e:
             if cache.last_run_result is None:
                 raise e
-        return cache.last_run_result
+            last_run_result = cache.last_run_result
+            cache.last_run_result = None
+            return last_run_result
+        return last_run_result
 
     return wrapped  # type: ignore
